@@ -156,8 +156,12 @@ class bigjob_agent:
         ###
         # Initiate coordination sub-system of both BJ agent and Pilot Data
         self.coordination = bigjob_coordination(server_connect_url=self.coordination_url)
-        # self.pilot_data_service = PilotDataService(coordination_url=self.coordination_url)
-        
+        try:
+            # initialize coordination subsystem of pilot data
+            self.pilot_data_service = PilotDataService(coordination_url=self.coordination_url)
+        except:
+            logger.warn("Pilot-Data could not be initialized.")
+            
         # update state of pilot job to running
         logger.debug("set state to : " +  str(bigjob.state.Running))
         self.coordination.set_pilot_state(self.base_url, str(bigjob.state.Running), False)
@@ -748,6 +752,7 @@ class bigjob_agent:
                 du.export(target_directory)
         except:
             logger.error("Stage-in of files failed.")
+            self.__print_traceback()
     
     
     def __stage_out_data_units(self, output_data=[], workingdirectory=None):
@@ -790,6 +795,7 @@ class bigjob_agent:
                         os.remove(f)
         except:
             logger.error("Stage out of files failed.")
+            self.__print_traceback()
     
     def __expand_file_pattern(self, filename_pattern, workingdirectory):
         """ expand files with wildcard * to a list """
@@ -854,7 +860,15 @@ class bigjob_agent:
                      + " Launch method: " + str(launch_method))
         return launch_method
     
-  
+    
+    def __print_traceback(self):
+        exc_type, exc_value, exc_traceback = sys.exc_info()
+        print "*** print_tb:"
+        traceback.print_tb(exc_traceback, limit=1, file=sys.stdout)
+        print "*** print_exception:"
+        traceback.print_exception(exc_type, exc_value, exc_traceback,
+                              limit=2, file=sys.stdout)
+        
 #########################################################
 #  main                                                 #
 #########################################################
