@@ -16,44 +16,59 @@ class State(object):
 
 
 class PilotComputeDescription(dict):
-    """ B{PilotComputeDescription.}
+    """ B{PilotComputeDescription (PCD).}
         
-        A PilotComputeDescription is a based on the SAGA Job Description.
+        A PilotComputeDescription is a based on the attributes defined on 
+        the SAGA Job Description.
 
         The PilotComputeDescription is used by the application to specify 
         what kind of PilotJobs it requires.
+        
+        Example::
+             pilot_compute_description = {
+                             "service_url": 'fork://localhost',
+                             "number_of_processes": 1,                             
+                             "working_directory": "/tmp/pilot-compute/",
+                             'affinity_datacenter_label': "eu-de-south",              
+                             'affinity_machine_label': "mymachine-1" 
+                            }
+        
+        B{Attention}: The PilotComputeDescription is mapped 1:1 to the underlying SAGA-Python (Bliss) 
+        job description, which is used for launching the pilot. Depending on the resource, it is required
+        to add additional attributes, e.g. some XSEDE/Torque resources require the specification
+        of both number_of_process and processes_per_node:
+        
+        Example::
+              pilot_compute_description = {
+                             "service_url": 'pbs+ssh://india.futuregrid.org',
+                             "number_of_processes": 8,
+                             "processes_per_node":8,                     
+                             "working_directory": "/N/u/luckow",
+                             'affinity_datacenter_label': "us-east-indiana",              
+                             'affinity_machine_label': "india" 
+                            }
+    
+        
+         
     """
 
     # Class members
     __slots__ = (
         # Pilot / Agent description
-        'executable',
-        'arguments',
-        'cleanup',
-        'environment',
-        'interactive',
-        'contact',
+        'service_url',
         'project',
-        'start_time',
         'working_directory',
         # I/O
         'input',
         'error',
         'output',
         'file_transfer',
+        
         # Parallelism
         'number_of_processes',      # Total number of processes to start
         'processes_per_host',       # Nr of processes per host
-        'threads_per_process',      # Nr of threads to start per process
-        'total_core_count',         # total number of cores requested
-        'spmd_variation',           # Type and startup mechanism
         
         # Requirements
-        'candidate_hosts',
-        'cpu_architecture',
-        'total_physical_memory', 
-        'operating_system_type',
-        'total_cpu_time',
         'wall_time_limit',
         'queue',
         
@@ -62,8 +77,10 @@ class PilotComputeDescription(dict):
         'affinity_machine_label',       # pilot jobs sharing the same label are located on the same machine
     )
 
+   
     def __init__(self):
-        pass
+        self.service_url.__doc__="SAGA-Python URL for respective resource manager, e.g. fork://localhost"
+
     
     
     def __setattr__(self, attr, value):
@@ -76,10 +93,10 @@ class PilotComputeDescription(dict):
     
 
 class PilotCompute(object):
-    """ PilotCompute (PilotJob). 
+    """ B{PilotCompute (PC)}. 
     
         This is the object that is returned by the PilotComputeService when a 
-        new PilotCompute is created based on a PilotComputeDescription.
+        new PilotCompute (aka Pilot-Job) is created based on a PilotComputeDescription.
 
         The PilotCompute object can be used by the application to keep track 
         of PilotComputes that are active.
@@ -143,7 +160,7 @@ class PilotCompute(object):
 #  Pilot ComputeService
 #
 class PilotComputeService(object):
-    """  PilotComputeService.
+    """  B{PilotComputeService (PCS).}
     
         The PilotComputeService is responsible for creating and managing 
         the PilotComputes.
@@ -203,8 +220,10 @@ class PilotComputeService(object):
 #  ComputeUnitService
 # 
 class ComputeUnitService(object):
-    """  ComputeUnitService.
+    """ B{ComputeUnitService (CUS).}
     
+        Please use ComputeDataService!
+        
         The ComputeUnitService is the application's interface to submit 
         ComputeUnits to the Pilot-Manager in the P* Model.
 
@@ -213,6 +232,7 @@ class ComputeUnitService(object):
 
         The ComputeUnitService is linked to a PilotComputeService for the actual 
         execution of the ComputeUnits.
+               
     """
 
     def __init__(self, wus_id=None):
@@ -291,7 +311,7 @@ class ComputeUnitService(object):
 #  ComuteUnitDescription
 # 
 class ComputeUnitDescription(dict):
-    """ B{ComputeUnitDescription.}
+    """ B{ComputeUnitDescription (CUD).}
     
         The ComputeUnitDescription is a task description based on 
         SAGA Job Description. 
@@ -301,7 +321,7 @@ class ComputeUnitDescription(dict):
         references to depended L{DataUnit}s. ComputeUnitDescription are submitted
         to the L{ComputeDataService}.
         
-        Example::
+        Format::
         
             compute_unit_description =            
                 {
@@ -344,6 +364,17 @@ class ComputeUnitDescription(dict):
                     'output_data': [<data unit url>, ... ]
                 }
             
+            Example::
+                    compute_unit_description = {
+                            "executable": "/bin/cat",
+                            "arguments": ["test.txt"],
+                            "number_of_processes": 1,
+                            "output": "stdout.txt",
+                            "error": "stderr.txt",   
+                            "input_data" : [data_unit.get_url()], # this stages the content of the data unit to the working directory of the compute unit
+                            "affinity_datacenter_label": "eu-de-south",              
+                            "affinity_machine_label": "mymachine-1" 
+                        }     
         ComputeUnitDescription objects are loosely typed. A dictionary containing the respective keys
         can be passed instead to the L{ComputeDataService}.
     """
@@ -363,7 +394,7 @@ class ComputeUnitDescription(dict):
 #  ComputeUnit(WU)
 # 
 class ComputeUnit(object):
-    """  ComputeUnit.
+    """ B{ComputeUnit (CU).}
     
         This is the object that is returned by the ComputeUnitService when a 
         new ComputeUnit is created based on a ComputeUnitDescription.
